@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Dict, Optional
+from typing import Dict, List, Optional
 
 import yaml
 from pydantic import BaseModel
@@ -25,6 +25,11 @@ class Config(BaseModel):
     project_name_override: Optional[str]
     package_name_override: Optional[str]
     package_version_override: Optional[str]
+    post_hooks: List[str] = [
+        "autoflake -i -r --remove-all-unused-imports --remove-unused-variables --ignore-init-module-imports .",
+        "isort .",
+        "black .",
+    ]
     field_prefix: str = "field_"
 
     @staticmethod
